Description Usage Arguments Value Author(s)
View source: R/compute.runs.expectancy.R
Adds header and computes run expectancies from a Retrosheet play-by-play data frame in the current working directory
1 | compute.runs.expectancy(season)
|
season |
Season of interest |
Data frame of Retrosheet data for season with additional variables added
Jim Albert
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.