pitch_count_graph: Pitch Count Graph

Description Usage Arguments Value Author(s)

View source: R/pitch_count_graph.R

Description

Constructs graph showing the mean runs value of plate appearances going through each possible count

Usage

1
  pitch_count_graph(d_season)

Arguments

d

Retrosheet play-by-play data frame with variables c01, c10, ...

Value

graph showing the mean runs value of plate appearances going through each count

Author(s)

Jim Albert


bayesball/PitchSequence documentation built on Jan. 19, 2021, 8:37 p.m.