Description Usage Arguments Value Author(s)
View source: R/pitch_count_graph.R
Constructs graph showing the mean runs value of plate appearances going through each possible count
1 | pitch_count_graph(d_season)
|
d |
Retrosheet play-by-play data frame with variables c01, c10, ... |
graph showing the mean runs value of plate appearances going through each count
Jim Albert
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.